@@ -14,7 +14,8 @@
  * Boston, MA 021110-1307, USA.
  */
 
-#define ARGV0_BUF_SIZE	64
+#ifndef __BTRFS_COMMANDS_H__
+#define __BTRFS_COMMANDS_H__
 
 struct cmd_struct {
 	const char *token;
@@ -62,10 +63,6 @@ struct cmd_group {
 /* btrfs.c */
 int prefixcmp(const char *str, const char *prefix);
 
-int check_argc_exact(int nargs, int expected);
-int check_argc_min(int nargs, int expected);
-int check_argc_max(int nargs, int expected);
-
 int handle_command_group(const struct cmd_group *grp, int argc,
 			 char **argv);
 
@@ -127,3 +124,5 @@ int test_issubvolume(char *path);
 
 /* send.c */
 char *get_subvol_name(char *mnt, char *full_path);
+
+#endif
